@@ -47,6 +47,17 @@ pub async fn interruptible<T, E: From<InterruptError>>(
     interruptible_straight(rx, f).await
 }
 
+pub async fn interruptible_sendable<T, E: From<InterruptError>>(
+    rx: Receiver<()>,
+    f: Arc<Mutex<dyn Future<Output=Result<T, E>> + Send + Unpin>>
+) -> Result<T, E>
+{
+    let f = f.clone();
+    let mut f = f.lock().await;
+    let f = Box::pin(&mut *f);
+    interruptible_straight(rx, f).await
+}
+
 pub async fn check_for_interrupt<E: From<InterruptError>>(
     rx: Receiver<()>,
 ) -> Result<(), E> {
@@ -56,12 +67,13 @@ pub async fn check_for_interrupt<E: From<InterruptError>>(
 /// TODO: More tests.
 #[cfg(test)]
 mod tests {
+    use std::future::Future;
     use std::sync::Arc;
     use async_channel::bounded;
     use futures::executor::block_on;
     use tokio::sync::Mutex;
 
-    use crate::{InterruptError, check_for_interrupt, interruptible};
+    use crate::{InterruptError, check_for_interrupt, interruptible, interruptible_sendable};
 
     #[derive(Debug, PartialEq, Eq)]
     struct AnotherError { }
@@ -153,4 +165,14 @@ mod tests {
             assert_eq!(test.h().await, Err(AnotherError::new().into()));
         });
     }
+
+    #[test]
+    fn check_interruptible_sendable() {
+        let (_tx, rx) = bounded::<()>(1);
+
+        // Check that `interruptible_sendable(...)` is a `Send` future.
+        let _: &(dyn Future<Output = Result<i32, InterruptError>> + Send) = &interruptible_sendable(rx, Arc::new(Mutex::new(Box::pin(async move {
+            Ok(123)
+        }))));
+    }
 }
